@@ -1,5 +1,6 @@
 /* GNU Gama C++ library
-   Copyright (C) 1999, 2002, 2003, 2010, 2011, 2012  Ales Cepek <cepek@gnu.org>
+   Copyright (C) 1999, 2002, 2003, 2010, 2011, 2012, 2014
+                 Ales Cepek <cepek@gnu.org>
 
    This file is part of the GNU Gama C++ library.
 
@@ -26,12 +27,12 @@
 #include <cstring>
 #include <gnu_gama/version.h>
 #include <gnu_gama/intfloat.h>
-#include <gnu_gama/xml/localnetwork.h>
+#include <gnu_gama/xml/localnetworkxml.h>
 #include <gnu_gama/xml/gkfparser.h>
 
 #include <gnu_gama/local/language.h>
 #include <gnu_gama/local/gamadata.h>
-#include <gnu_gama/local/newnetwork.h>
+#include <gnu_gama/local/network.h>
 #include <gnu_gama/local/acord.h>
 #include <gnu_gama/local/svg.h>
 #include <gnu_gama/local/html.h>
@@ -48,6 +49,7 @@
 #include <gnu_gama/local/results/text/residuals_observations.h>
 #include <gnu_gama/local/results/text/error_ellipses.h>
 #include <gnu_gama/local/results/text/test_linearization.h>
+#include <gnu_gama/local/xmlerror.h>
 
 namespace {
 int help()
@@ -116,7 +118,11 @@ int help()
 
   return 1;
 }
-}
+
+GNU_gama::local::XMLerror xmlerr;
+
+}  // unnamed namespace
+
 
 
 int main(int argc, char **argv)
@@ -148,9 +154,6 @@ int main(int argc, char **argv)
     const char* argv_sqlitedb = 0;
 #endif
 
-    bool correction_to_ellipsoid = false;
-    GNU_gama::Ellipsoid el;
-    double latitude = M_PI/4.0;
 
     for (int i=1; i<argc; i++)
       {
@@ -196,6 +199,11 @@ int main(int argc, char **argv)
           return help();
       }
 
+    // implicit output
+    if (!argv_txtout && !argv_htmlout && !argv_xmlout) argv_xmlout = "-";
+
+    if (argv_xmlout) xmlerr.setXmlOutput(argv_xmlout);
+
 #ifdef GNU_GAMA_LOCAL_SQLITE_READER
     if (argv_confname && argv_readonly) return help();
     if (!argv_1 && !argv_sqlitedb) return help();
@@ -257,8 +265,6 @@ int main(int argc, char **argv)
           return help();
       }
 
-    LocalNetwork* IS = 0;
-
     if (argv_algo)
       {
         const std::string algorithm = argv_algo;
@@ -266,10 +272,10 @@ int main(int argc, char **argv)
             algorithm != "svd"      &&
             algorithm != "cholesky" &&
             algorithm != "envelope" ) return help();
-
-        IS = newLocalNetwork(algorithm);
       }
 
+    LocalNetwork* IS = new LocalNetwork;
+
 #ifdef GNU_GAMA_LOCAL_SQLITE_READER
     if (argv_sqlitedb)
       {
@@ -282,10 +288,8 @@ int main(int argc, char **argv)
     else
 #endif
       {
-        if (IS == 0) IS = newLocalNetwork();        // implicit algorithm
-
         ifstream soubor(argv_1);
-        GKFparser gkf(IS->PD, IS->OD);
+        GKFparser gkf(*IS);
         try
           {
             char c;
@@ -306,27 +310,36 @@ int main(int argc, char **argv)
                 gkf.xml_parse(radek.c_str(), n, konec);
               }
             while (!konec);
-
-            IS->apriori_m_0(gkf.m0_apr );
-            IS->conf_pr    (gkf.konf_pr);
-            IS->tol_abs    (gkf.tol_abs);
-
-            IS->update_constrained_coordinates(gkf.update_constr);
-
-            if (gkf.typ_m0_apriorni)
-              IS->set_m_0_apriori();
-            else
-              IS->set_m_0_aposteriori();
-
-            IS->description = gkf.description;
-            IS->epoch = gkf.epoch;
           }
         catch (const GNU_gama::local::ParserException& v) {
+          if (xmlerr.isValid())
+            {
+              xmlerr.setDescription(T_GaMa_exception_2a);
+              std::string t, s = v.what();
+              for (std::string::iterator i=s.begin(), e=s.end(); i!=e; ++i)
+                {
+                  if      (*i == '<') t += "\"";
+                  else if (*i == '>') t += "\"";
+                  else                t += *i;
+                }
+              xmlerr.setDescription(t);
+              xmlerr.setLineNumber (v.line);
+              //xmlerr.setDescription(T_GaMa_exception_2b);
+              return xmlerr.write_xml("gamaLocalParserError");
+            }
+
           cerr << "\n" << T_GaMa_exception_2a << "\n\n"
                << T_GaMa_exception_2b << v.line << " : " << v.what() << endl;
           return 3;
         }
         catch (const GNU_gama::local::Exception& v) {
+          if (xmlerr.isValid())
+            {
+              xmlerr.setDescription(T_GaMa_exception_2a);
+              xmlerr.setDescription(v.what());
+              return xmlerr.write_xml("gamaLocalException");
+            }
+
           cerr << "\n" <<T_GaMa_exception_2a << "\n"
                << "\n***** " << v.what() << "\n\n";
           return 2;
@@ -338,6 +351,13 @@ int main(int argc, char **argv)
           }
       }
 
+    if (argv_algo)
+      {
+        IS->set_algorithm(argv_algo);
+      }
+
+    if (!IS->has_algorithm()) IS->set_algorithm();
+
     if (argv_angles)
       {
         if (!strcmp("400", argv_angles))
@@ -361,25 +381,27 @@ int main(int argc, char **argv)
 
     if (argv_latitude)
       {
-        if ( !GNU_gama::IsFloat(string(argv_latitude)) )
-          return help();
+        double latitude;
+        if (!GNU_gama::deg2gon(argv_latitude, latitude))
+          {
+            if (!GNU_gama::IsFloat(string(argv_latitude)))
+              return help();
 
-        latitude = atof(argv_latitude) * M_PI / (IS->gons() ? 200 : 180);
+            latitude = atof(argv_latitude);
+          }
 
-        correction_to_ellipsoid = true;
+        IS->set_latitude(latitude * M_PI/200);
       }
 
-    GNU_gama::set(&el, GNU_gama::ellipsoid_wgs84);
 
     if (argv_ellipsoid)
       {
         using namespace GNU_gama;
 
         gama_ellipsoid gama_el = ellipsoid(argv_ellipsoid);
-        if  ( (gama_el == ellipsoid_unknown) || GNU_gama::set(&el,  gama_el) )
-          return help();
+        if  (gama_el == ellipsoid_unknown) return help();
 
-        correction_to_ellipsoid = true;
+        IS->set_ellipsoid(argv_ellipsoid);
       }
 
 
@@ -408,9 +430,13 @@ int main(int argc, char **argv)
         acord.execute();
         ReducedObservationsText(IS,&(acord.RO), cout);
 
-        if (correction_to_ellipsoid)
+        if (IS->correction_to_ellipsoid())
           {
-            ReduceToEllipsoid reduce_to_el(IS->PD, IS->OD, el, latitude);
+            using namespace GNU_gama;
+            gama_ellipsoid elnum = ellipsoid(IS->ellipsoid().c_str());
+            Ellipsoid el;
+            GNU_gama::set(&el, elnum);
+            ReduceToEllipsoid reduce_to_el(IS->PD, IS->OD, el, IS->latitude());
             reduce_to_el.execute();
             ReducedObservationsToEllipsoidText(IS, reduce_to_el.getMap(), cout);
           }
@@ -420,11 +446,24 @@ int main(int argc, char **argv)
       }
     catch(GNU_gama::local::Exception e)
       {
+        if (xmlerr.isValid())
+          {
+            xmlerr.setDescription(e.what());
+            return xmlerr.write_xml("gamaLocalException");
+          }
+
         cerr << e.what() << endl;
         return 1;
       }
     catch(...)
       {
+        if (xmlerr.isValid())
+          {
+            xmlerr.setDescription("Gama / Acord: "
+                                  "approximate coordinates failed");
+            return xmlerr.write_xml("gamaLocalApproximateCoordinates");
+          }
+
         cerr << "Gama / Acord: approximate coordinates failed\n\n";
         return 1;
       }
@@ -521,9 +560,6 @@ int main(int argc, char **argv)
             IS->project_equations(opr);
           }
 
-        // implicit output
-        if (!argv_txtout && !argv_htmlout && !argv_xmlout) argv_xmlout = "-";
-
         if (argv_htmlout)
           {
             GNU_gama::local::GamaLocalHTML html(IS);
@@ -565,6 +601,12 @@ int main(int argc, char **argv)
 #ifdef GNU_GAMA_LOCAL_SQLITE_READER
   catch(const GNU_gama::Exception::sqlitexc& gamalite)
     {
+      if (xmlerr.isValid())
+        {
+          xmlerr.setDescription(gamalite.what());
+          return xmlerr.write_xml("gamaLocalSqlite");
+        }
+
       std::cout << "\n" << "****** " << gamalite.what() << "\n\n";
       return 1;
     }
@@ -572,6 +614,14 @@ int main(int argc, char **argv)
   catch(const GNU_gama::Exception::adjustment& choldec)
     {
       using namespace GNU_gama::local;
+
+      if (xmlerr.isValid())
+        {
+          xmlerr.setDescription(T_GaMa_solution_ended_with_error);
+          xmlerr.setDescription(choldec.str);
+          return xmlerr.write_xml("gamaLocalAdjustment");
+        }
+
       std::cout << "\n" << T_GaMa_solution_ended_with_error << "\n\n"
                 << "****** " << choldec.str << "\n\n";
       return 1;
@@ -579,15 +629,35 @@ int main(int argc, char **argv)
   catch (const GNU_gama::local::Exception& V)
     {
       using namespace GNU_gama::local;
+
+      if (xmlerr.isValid())
+        {
+          xmlerr.setDescription(T_GaMa_solution_ended_with_error);
+          xmlerr.setDescription(V.what());
+          return xmlerr.write_xml("gamaLocalException");
+        }
+
       std::cout << "\n" << T_GaMa_solution_ended_with_error << "\n\n"
                 << "****** " << V.what() << "\n\n";
       return 1;
     }
   catch (std::exception& stde) {
+    if (xmlerr.isValid())
+      {
+        xmlerr.setDescription(stde.what());
+        return xmlerr.write_xml("gamaLocalStdException");
+      }
+
     std::cout << "\n" << stde.what() << "\n\n";
   }
   catch(...) {
     using namespace GNU_gama::local;
+
+    if (xmlerr.isValid())
+      {
+        return xmlerr.write_xml("gamaLocalUnknownException");
+      }
+
     std::cout << "\n" << T_GaMa_internal_program_error << "\n\n";
     return 1;
   }
