@@ -1,9 +1,9 @@
-/*  
+/*
     GNU Gama -- adjustment of geodetic networks
     Copyright (C) 2005  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
-    
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,10 +19,6 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: g3_model_write_xml_adjustment_results.cpp,v 1.10 2007/06/26 15:04:10 cepek Exp $
- */
-
 #include <iomanip>
 #include <gnu_gama/g3/g3_model.h>
 #include <gnu_gama/g3/g3_cluster.h>
@@ -36,10 +32,10 @@ using namespace GNU_gama::g3;
 
 using GNU_gama::Index;
 
-namespace 
+namespace
 {
-  class WriteAdjustedXML :  
-    public GNU_gama::ObservationVisitor,
+  class WriteAdjustedXML :
+    public GNU_gama::BaseVisitor,
     public GNU_gama::Visitor<Angle>,
     public GNU_gama::Visitor<Azimuth>,
     public GNU_gama::Visitor<Distance>,
@@ -51,42 +47,42 @@ namespace
   {
   public:
 
-    WriteAdjustedXML(GNU_gama::g3::Model* m, std::ostream& o) 
-      : model(m), out(o) 
+    WriteAdjustedXML(GNU_gama::g3::Model* m, std::ostream& o)
+      : model(m), out(o)
     {
     }
 
     void visit(Angle* p)
     {
-      model->write_xml_adjusted(out, p, index); 
+      model->write_xml_adjusted(out, p, index);
     }
     void visit(Azimuth* p)
     {
-      model->write_xml_adjusted(out, p, index); 
+      model->write_xml_adjusted(out, p, index);
     }
     void visit(Distance* p)
     {
-      model->write_xml_adjusted(out, p, index); 
+      model->write_xml_adjusted(out, p, index);
     }
     void visit(Height* p)
     {
-      model->write_xml_adjusted(out, p, index); 
+      model->write_xml_adjusted(out, p, index);
     }
     void visit(HeightDiff* p)
     {
-      model->write_xml_adjusted(out, p, index); 
+      model->write_xml_adjusted(out, p, index);
     }
     void visit(Vector* p)
     {
-      model->write_xml_adjusted(out, p, index); 
+      model->write_xml_adjusted(out, p, index);
     }
     void visit(XYZ* p)
     {
-      model->write_xml_adjusted(out, p, index); 
+      model->write_xml_adjusted(out, p, index);
     }
     void visit(ZenithAngle* p)
     {
-      model->write_xml_adjusted(out, p, index); 
+      model->write_xml_adjusted(out, p, index);
     }
 
     Index index;
@@ -127,24 +123,24 @@ void Model::write_xml_rejected_observations(std::ostream& out)
 
   out << "\n<rejected-observations>\n";
 
-  for (RejectedObs::iterator 
+  for (RejectedObs::iterator
          i=rejected_obs.begin(), e=rejected_obs.end(); i!=e; ++i)
     {
       Model::Rejected& robs = *i;
 
       string tag;
-      switch (robs.criterion) 
+      switch (robs.criterion)
         {
         case Model::Rejected::rhs: tag = "rhs";     break;
         default:                   tag = "unknown"; break;
         }
 
       out << "\n<rejected>\t<reason>" << tag << "</reason>\n";
-      
+
       robs.observation->accept(&visitor);
       out << "        ";
       for (int i=0; i<robs.observation->dimension(); i++)
-        out << "<flt>" << robs.data[i] << "</flt> ";     
+        out << "<flt>" << robs.data[i] << "</flt> ";
 
       out << "\n</rejected>\n";
     }
@@ -155,7 +151,7 @@ void Model::write_xml_rejected_observations(std::ostream& out)
 
 
 void Model::write_xml_adjustment_results_statistics(std::ostream& out)
-{ 
+{
   out << "\n<adjustment-statistics>\n\n";
 
   Adj::algorithm alg = adj->get_algorithm();
@@ -169,17 +165,17 @@ void Model::write_xml_adjustment_results_statistics(std::ostream& out)
 
   {
     gama_ellipsoid id = gama_ellipsoid(ellipsoid.id);
-    
+
     out.setf(ios_base::fixed, ios_base::floatfield);
     out << "<ellipsoid> "
         << "<caption> " << gama_ellipsoid_caption[id] << " </caption>\n";
-    out << "            <id>      " << gama_ellipsoid_id[id] 
+    out << "            <id>      " << gama_ellipsoid_id[id]
         << "         </id>\n";
     out.precision(5);
-    out << "            <a>       " << ellipsoid.a() << " </a>\n"; 
+    out << "            <a>       " << ellipsoid.a() << " </a>\n";
     out.precision(5);
-    out << "            <b>       " << ellipsoid.b() << " </b>\n"; 
-    out << "            </ellipsoid>\n\n"; 
+    out << "            <b>       " << ellipsoid.b() << " </b>\n";
+    out << "            </ellipsoid>\n\n";
   }
 
   out << "<parameters>" << setw(5) << dm_cols       << " </parameters>\n";
@@ -194,27 +190,27 @@ void Model::write_xml_adjustment_results_statistics(std::ostream& out)
   out << "<sum-of-squares>        " << rtr << " </sum-of-squares>\n";
 
   double sigma_apriori = apriori_sd*apriori_sd;
-  out << "<apriori-variance>      " 
+  out << "<apriori-variance>      "
       << sigma_apriori << " </apriori-variance>\n";
 
   double sigma_aposteriori = aposteriori_sd*aposteriori_sd;
-  out << "<aposteriori-variance>  " 
+  out << "<aposteriori-variance>  "
       << sigma_aposteriori <<" </aposteriori-variance>\n";
-  
+
   out << "<variance-factor-used>  ";
   if (actual_sd == aposteriori)
     out << "aposteriori";
   else
     out << "    apriori";
   out <<" </variance-factor-used>\n";
-  
+
   out << "<design-matrix-graph>  ";
   if (graph_is_connected())
     out << "   connected";
   else
     out << "disconnected";
   out <<" </design-matrix-graph>\n";
-  
+
 
 
   out << "\n</adjustment-statistics>\n\n";
@@ -227,20 +223,20 @@ void Model::write_xml_adjustment_results_points      (std::ostream& out)
   out << "\n"
     "<!-- adjustment results    : dn / de / du  are in millimeters -->\n"
     "<!-- deflection of vertical: db / dl       are in arc seconds -->\n\n";
-  
+
   out << "<adjustment-results>\n";
 
-  for (ParameterList::iterator 
+  for (ParameterList::iterator
          i=par_list->begin(), e=par_list->end(); i!=e; ++i)
     {
       (*i)->write_xml_init();
     }
-  for (ParameterList::iterator 
+  for (ParameterList::iterator
          i=par_list->begin(), e=par_list->end(); i!=e; ++i)
     {
       (*i)->write_xml(out);
     }
-  
+
   out << "\n</adjustment-results>\n\n";
 }
 
@@ -252,7 +248,7 @@ void Model::write_xml_adjustment_results_observations(std::ostream& out)
 
   WriteAdjustedXML  write_xml(this, out);
   Index index = 1;
-  for (ObservationList::iterator 
+  for (ObservationList::iterator
          i=active_obs->begin(), e=active_obs->end(); i!=e; ++i)
     {
       write_xml.index = index;
@@ -267,8 +263,8 @@ void Model::write_xml_adjustment_results_observations(std::ostream& out)
 // ==========================================================================
 
 
-void Model::write_xml_adjusted_stdev(const char* prefix, 
-                                     std::ostream& out, 
+void Model::write_xml_adjusted_stdev(const char* prefix,
+                                     std::ostream& out,
                                      const Observation* obs,
                                      Index obs_dim_index,
                                      Index index)
@@ -287,20 +283,20 @@ void Model::write_xml_adjusted_stdev(const char* prefix,
   double adj_stdev     = sqrt( cov_bb(index, index) );
 
   out << ntab << "<" << prefix << "stdev-obs>"
-      << setw(width) << obs_stdev  
+      << setw(width) << obs_stdev
       << " </" << prefix << "stdev-obs>\n";
   //out << tab << "<" << prefix << "stdev-res>"
-  //    << setw(width) << res_stdev  
+  //    << setw(width) << res_stdev
   //    << " </" << prefix << "stdev-res>\n";
   out << tab << "<" << prefix << "stdev-adj>"
-      << setw(width) << adj_stdev  
+      << setw(width) << adj_stdev
       << " </" << prefix << "stdev-adj>\n";
 
   out.precision(prec);
 }
 
 
-void Model::write_xml_adjusted_cov_xyz(std::ostream& out, 
+void Model::write_xml_adjusted_cov_xyz(std::ostream& out,
                                        const Observation* obs,
                                        Index index)
 {
@@ -311,8 +307,8 @@ void Model::write_xml_adjusted_cov_xyz(std::ostream& out,
   double cyz = cov_bb(index, index+1);   index++;
   double czz = cov_bb(index, index  );
 
-  
-  const std::ios_base::fmtflags format = out.setf(std::ios_base::scientific, 
+
+  const std::ios_base::fmtflags format = out.setf(std::ios_base::scientific,
                                                   std::ios_base::floatfield);
   const int prec = out.precision(7);
   const int width = 14;
@@ -357,22 +353,22 @@ void Model::write_xml_adjusted(std::ostream& out, const Distance* d, Index index
       << "<to>"    << d->to   << "</to> "
       << "<ind>" << index   << "</ind>\n";
 
-  const std::ios_base::fmtflags format = out.setf(std::ios_base::fixed, 
+  const std::ios_base::fmtflags format = out.setf(std::ios_base::fixed,
                                                   std::ios_base::floatfield);
   const int prec  = out.precision(5);
   const int width = 13;
 
   double rd = adj->r()(index)/Linear().scale();
-  out << "\n        <observed>" << setw(13) << d->obs()      
+  out << "\n        <observed>" << setw(13) << d->obs()
       << " </observed>";
   out << "\n";
-  out << "        <residual>" << setw(13) << rd          
+  out << "        <residual>" << setw(13) << rd
       << " </residual>";
   out << "\n";
-  out << "        <adjusted>" << setw(13) << d->obs()+rd  
+  out << "        <adjusted>" << setw(13) << d->obs()+rd
       << " </adjusted>";
   out << "\n";
-  
+
   write_xml_adjusted_stdev("", out, d, 0, index);
 
   out << "        </distance>\n";
@@ -387,44 +383,44 @@ void Model::write_xml_adjusted(std::ostream& out, const Vector* v, Index index)
 {
   out << "\n<vector> "
       << "<from>"  << v->from << "</from> "
-      << "<to>"    << v->to   << "</to> " 
+      << "<to>"    << v->to   << "</to> "
       << "<ind>" << index   << "</ind>\n";
 
-  const std::ios_base::fmtflags format = out.setf(std::ios_base::fixed, 
+  const std::ios_base::fmtflags format = out.setf(std::ios_base::fixed,
                                                   std::ios_base::floatfield);
   const int prec  = out.precision(5);
   const int width = 13;
 
   double rdx = adj->r()(index)/Linear().scale();
-  out << "\n        <dx-observed>" << setw(width) << v->dx()      
+  out << "\n        <dx-observed>" << setw(width) << v->dx()
       << " </dx-observed>";
   out << "\n";
-  out << "        <dx-residual>" << setw(width) << rdx          
+  out << "        <dx-residual>" << setw(width) << rdx
       << " </dx-residual>";
   out << "\n";
-  out << "        <dx-adjusted>" << setw(width) << v->dx()+rdx  
+  out << "        <dx-adjusted>" << setw(width) << v->dx()+rdx
       << " </dx-adjusted>";
   out << "\n";
 
   double rdy = adj->r()(index+1)/Linear().scale();
-  out << "\n        <dy-observed>" << setw(width) << v->dy()      
+  out << "\n        <dy-observed>" << setw(width) << v->dy()
       << " </dy-observed>";
   out << "\n";
-  out << "        <dy-residual>" << setw(width) << rdy          
+  out << "        <dy-residual>" << setw(width) << rdy
       << " </dy-residual>";
   out << "\n";
-  out << "        <dy-adjusted>" << setw(width) << v->dy()+rdy  
+  out << "        <dy-adjusted>" << setw(width) << v->dy()+rdy
       << " </dy-adjusted>";
   out << "\n";
 
   double rdz = adj->r()(index+2)/Linear().scale();
-  out << "\n        <dz-observed>" << setw(width) << v->dz()      
+  out << "\n        <dz-observed>" << setw(width) << v->dz()
       << " </dz-observed>";
   out << "\n";
-  out << "        <dz-residual>" << setw(width) << rdz          
+  out << "        <dz-residual>" << setw(width) << rdz
       << " </dz-residual>";
   out << "\n";
-  out << "        <dz-adjusted>" << setw(width) << v->dz()+rdz  
+  out << "        <dz-adjusted>" << setw(width) << v->dz()+rdz
       << " </dz-adjusted>";
   out << "\n";
 
@@ -433,7 +429,7 @@ void Model::write_xml_adjusted(std::ostream& out, const Vector* v, Index index)
   write_xml_adjusted_stdev("dz-", out, v, 2, index);
 
   write_xml_adjusted_cov_xyz(out, v, index);
-  
+
   out << "        </vector>\n";
 
   out.precision(prec);
@@ -448,19 +444,19 @@ void Model::write_xml_adjusted(std::ostream& out, const Height* h, Index index)
       << "<id>" << h->id << "</id> "
       << "<ind>" << index   << "</ind>\n";
 
-  const std::ios_base::fmtflags format = out.setf(std::ios_base::fixed, 
+  const std::ios_base::fmtflags format = out.setf(std::ios_base::fixed,
                                                   std::ios_base::floatfield);
   const int prec  = out.precision(5);
   const int width = 13;
 
   double rdh = adj->r()(index)/Linear().scale();
-  out << "\n        <observed>" << setw(width) << h->obs()      
+  out << "\n        <observed>" << setw(width) << h->obs()
       << " </observed>";
   out << "\n";
-  out << "        <residual>" << setw(width) << rdh          
+  out << "        <residual>" << setw(width) << rdh
       << " </residual>";
   out << "\n";
-  out << "        <adjusted>" << setw(width) << h->obs()+rdh  
+  out << "        <adjusted>" << setw(width) << h->obs()+rdh
       << " </adjusted>";
   out << "\n";
 
@@ -480,19 +476,19 @@ void Model::write_xml_adjusted(std::ostream& out, const HeightDiff* hd, Index in
       << "<from>" << hd->from << "</from> <to>" << hd->to << "</to> "
       << "<ind>" << index << "</ind>\n";
 
-  const std::ios_base::fmtflags format = out.setf(std::ios_base::fixed, 
+  const std::ios_base::fmtflags format = out.setf(std::ios_base::fixed,
                                                   std::ios_base::floatfield);
   const int prec  = out.precision(5);
   const int width = 13;
- 
+
  double rdhd = adj->r()(index)/Linear().scale();
-  out << "\n        <observed>" << setw(width) << hd->obs()      
+  out << "\n        <observed>" << setw(width) << hd->obs()
       << " </observed>";
   out << "\n";
-  out << "        <residual>" << setw(width) << rdhd          
+  out << "        <residual>" << setw(width) << rdhd
       << " </residual>";
   out << "\n";
-  out << "        <adjusted>" << setw(width) << hd->obs()+rdhd  
+  out << "        <adjusted>" << setw(width) << hd->obs()+rdhd
       << " </adjusted>";
   out << "\n";
 
@@ -512,41 +508,41 @@ void Model::write_xml_adjusted(std::ostream& out, const XYZ* xyz, Index index)
       << "<id>" << xyz->id << "</id> "
       << "<ind>" << index   << "</ind>\n";
 
-  const std::ios_base::fmtflags format = out.setf(std::ios_base::fixed, 
+  const std::ios_base::fmtflags format = out.setf(std::ios_base::fixed,
                                                   std::ios_base::floatfield);
   const int prec  = out.precision(5);
   const int width = 14;
 
   double rx = adj->r()(index)/Linear().scale();
-  out << "\n        <x-observed>" << setw(width) << xyz->x()      
+  out << "\n        <x-observed>" << setw(width) << xyz->x()
       << " </x-observed>";
   out << "\n";
-  out << "        <x-residual>" << setw(width) << rx          
+  out << "        <x-residual>" << setw(width) << rx
       << " </x-residual>";
   out << "\n";
-  out << "        <x-adjusted>" << setw(width) << xyz->x()+rx  
+  out << "        <x-adjusted>" << setw(width) << xyz->x()+rx
       << " </x-adjusted>";
   out << "\n";
 
   double ry = adj->r()(index+1)/Linear().scale();
-  out << "\n        <y-observed>" << setw(width) << xyz->y()      
+  out << "\n        <y-observed>" << setw(width) << xyz->y()
       << " </y-observed>";
   out << "\n";
-  out << "        <y-residual>" << setw(width) << ry          
+  out << "        <y-residual>" << setw(width) << ry
       << " </y-residual>";
   out << "\n";
-  out << "        <y-adjusted>" << setw(width) << xyz->y()+ry  
+  out << "        <y-adjusted>" << setw(width) << xyz->y()+ry
       << " </y-adjusted>";
   out << "\n";
 
   double rz = adj->r()(index+2)/Linear().scale();
-  out << "\n        <z-observed>" << setw(width) << xyz->z()      
+  out << "\n        <z-observed>" << setw(width) << xyz->z()
       << " </z-observed>";
   out << "\n";
-  out << "        <z-residual>" << setw(width) << rz          
+  out << "        <z-residual>" << setw(width) << rz
       << " </z-residual>";
   out << "\n";
-  out << "        <z-adjusted>" << setw(width) << xyz->z()+rz  
+  out << "        <z-adjusted>" << setw(width) << xyz->z()+rz
       << " </z-adjusted>";
   out << "\n";
 
@@ -555,7 +551,7 @@ void Model::write_xml_adjusted(std::ostream& out, const XYZ* xyz, Index index)
   write_xml_adjusted_stdev("z-", out, xyz, 2, index);
 
   write_xml_adjusted_cov_xyz(out, xyz, index);
-  
+
   out << "        </xyz>\n";
 
   out.precision(prec);
