@@ -1,7 +1,7 @@
 /* GNU Gama -- adjustment of geodetic networks
     Copyright (C) 1999, 2006, 2010  Ales Cepek <cepek@fsv.cvut.cz>
                   2011  Vaclav Petras <wenzeslaus@gmail.com>
-                  2012, 2013  Ales Cepek <cepek@gnu.org>
+                  2012, 2013, 2014  Ales Cepek <cepek@gnu.org>
 
    This file is part of the GNU Gama C++ library.
 
@@ -39,6 +39,7 @@
 #include <gnu_gama/statan.h>
 #include <gnu_gama/sparse/smatrix_graph.h>
 #include <gnu_gama/version.h>
+#include <gnu_gama/ellipsoids.h>
 
 using namespace std;
 using namespace GNU_gama::local;
@@ -201,6 +202,12 @@ private:
     }
 };
 
+
+
+//##########################################################################
+
+
+
 LocalNetwork::LocalNetwork()
   : pocbod_(0), tst_redbod_(false), pocmer_(0), tst_redmer_(false),
     m_0_apr_(10), konf_pr_(0.95), tol_abs_(1000),
@@ -209,11 +216,16 @@ LocalNetwork::LocalNetwork()
     gons_(true)
 {
   least_squares = 0;
-
-  epoch = 0.0;
   Asp = 0;
 
-  xml_covband_ = -1;
+  xml_covband_   = -1;
+  // epoch_         = 0.0;
+  // has_epoch_     = false;
+  // latitude_      = M_PI/4.0;
+  // has_latitude_  = false;
+  // ellipsoid_     = "";
+  // has_ellipsoid_ = false;
+  clear_nullable_data();
 }
 
 
@@ -224,6 +236,140 @@ LocalNetwork::~LocalNetwork()
 }
 
 
+Double LocalNetwork::cond()
+{
+  return least_squares->cond();
+}
+
+
+bool LocalNetwork::lindep(Index i)
+{
+  return least_squares->lindep(i);
+}
+
+
+std::string LocalNetwork::algorithm() const
+{
+  return algorithm_;
+}
+
+
+bool LocalNetwork::has_algorithm() const
+{
+  return has_algorithm_;
+}
+
+
+void LocalNetwork::set_algorithm(std::string alg)
+{
+  typedef GNU_gama::local::MatVecException     MVE;
+  typedef GNU_gama::AdjEnvelope<Double, Index, MVE> OLS_env;
+  typedef GNU_gama::AdjGSO     <Double,        MVE> OLS_gso;
+  typedef GNU_gama::AdjSVD     <Double,        MVE> OLS_svd;
+  typedef GNU_gama::AdjCholDec <Double,        MVE> OLS_chol;
+
+  AdjBase* adjb;
+  if      (alg == "gso" )     adjb = new OLS_gso;
+  else if (alg == "svd" )     adjb = new OLS_svd;
+  else if (alg == "cholesky") adjb = new OLS_chol;
+  else if (alg == "envelope") adjb = new OLS_env;
+  else
+    {
+      alg  = "envelope";
+      adjb = new OLS_env;
+    }
+  algorithm_ = alg;
+  has_algorithm_ = true;
+
+  if (least_squares != 0) delete least_squares;
+  least_squares = adjb;
+
+  update(Points);
+}
+
+
+int LocalNetwork::xml_covband() const
+{
+  return xml_covband_;
+}
+
+
+void LocalNetwork::set_xml_covband(int val)
+{
+  if (val < -1) val = -1;
+  xml_covband_ = val;
+}
+
+
+double LocalNetwork::epoch() const
+{
+  return epoch_;
+}
+
+
+bool LocalNetwork::has_epoch() const
+{
+  return has_epoch_;
+}
+
+
+void LocalNetwork::set_epoch(double val)
+{
+  has_epoch_ = true;
+  epoch_ = val;
+}
+
+
+double LocalNetwork::latitude() const
+{
+  return latitude_;
+}
+
+
+bool LocalNetwork::has_latitude() const
+{
+  return has_latitude_;
+}
+
+
+void LocalNetwork::set_latitude(double val)
+{
+  has_latitude_ = true;
+  latitude_ = val;
+}
+
+
+std::string LocalNetwork::ellipsoid() const
+{
+  return ellipsoid_;
+}
+
+
+bool LocalNetwork::has_ellipsoid() const
+{
+return has_ellipsoid_;
+}
+
+void LocalNetwork::set_ellipsoid(std::string e)
+{
+  if (GNU_gama::ellipsoid(e.c_str())) ellipsoid_ = e;
+  else                                set_ellipsoid();
+  has_ellipsoid_ = true;
+}
+
+
+bool LocalNetwork::correction_to_ellipsoid() const
+{
+  return has_latitude_ || has_ellipsoid_;
+}
+
+
+void LocalNetwork::clear_nullable_data()
+{
+  has_algorithm_ = has_epoch_ = has_latitude_ = has_ellipsoid_ = false;
+}
+
+
 void LocalNetwork::revision_points()
 {
   if (tst_redbod_) return;
@@ -294,7 +440,7 @@ void LocalNetwork::revision_observations()
       if (StandPoint* sp = dynamic_cast<StandPoint*>(*cit))
         {
           // 1.3.08 *** check for directions pointing to the same targer
-          set<PointID> targets;
+          std::set<PointID> targets;
 
           int active_directions = 0;
           for (ObservationList::iterator i=sp->observation_list.begin();
@@ -303,7 +449,7 @@ void LocalNetwork::revision_observations()
               if (const Direction* d = dynamic_cast<const Direction*>(*i))
                 if (d->active())
                   {
-                    set<PointID>::const_iterator s = targets.find( d->to() );
+                    std::set<PointID>::const_iterator s = targets.find( d->to() );
                     if (s == targets.end())
                       {
                         active_directions++;
@@ -1153,8 +1299,3 @@ void LocalNetwork::vyrovnani_()
   }
 
 }
-
-
-
-
-
