@@ -1,5 +1,5 @@
 /* GNU Gama -- adjustment of geodetic networks
-   Copyright (C) 1999, 2006, 2012  Ales Cepek <cepek@gnu.org>
+   Copyright (C) 1999, 2006, 2012, 2014  Ales Cepek <cepek@gnu.org>
 
    This file is part of the GNU Gama C++ library.
 
@@ -55,13 +55,10 @@ namespace GNU_gama { namespace local
     LocalNetwork();
     virtual ~LocalNetwork();
 
-    void set_algorithm(AdjBase* adjb) { least_squares = adjb; }
-
     PointData        PD;      // point list
     ObservationData  OD;      // observation list
 
     std::string   description;
-    double        epoch;
 
 
     // ...  information on points removed from adjustment  .................
@@ -197,9 +194,8 @@ namespace GNU_gama { namespace local
     Double qbb(Index i, Index j) { return least_squares->q_bb(i,j); }
     Double qbx(Index i, Index j) { return least_squares->q_bx(i,j); }
 
-    virtual Double cond() = 0;
-    virtual bool lindep(Index i) = 0;
-    virtual const char* const algorithm() const = 0;
+    Double cond();
+    bool lindep(Index i);
 
     void refine_approx();
 
@@ -274,28 +270,49 @@ namespace GNU_gama { namespace local
     void set_gons()      { gons_ = true;  Observation::gons = true;  }
     void set_degrees()   { gons_ = false; Observation::gons = false; }
 
-    void set_xml_covband(int band=-1) { xml_covband_ = band; }
-    int  xml_covband() const { return xml_covband_; }
-
     // ...  connected network  .............................................
 
     bool connected_network() const { return design_matrix_graph_is_connected; }
 
-
+    std::string algorithm() const;
+    bool        has_algorithm() const;
+    void        set_algorithm(std::string alg = std::string());
+    int         xml_covband() const;
+    void        set_xml_covband(int value=-1);
+    double      epoch() const;
+    bool        has_epoch() const;
+    void        set_epoch(double=0.0);
+    double      latitude() const;
+    bool        has_latitude() const;
+    void        set_latitude(double);
+    std::string ellipsoid() const;
+    bool        has_ellipsoid() const;
+    void        set_ellipsoid(std::string="wgs84");
+    bool        correction_to_ellipsoid() const;
+    void        clear_nullable_data();
 
     // #####################################################################
 
 
   private:
 
-    // ObservationList      RSM;      // revised observation list
+    int         xml_covband_;         // output XML xyz cov bandWidth
+    std::string algorithm_;           // algorithm name or empty string
+    bool        has_algorithm_;
+    double      epoch_;
+    bool        has_epoch_;
+    double      latitude_;
+    bool        has_latitude_;
+    std::string ellipsoid_;
+    bool        has_ellipsoid_;
+
     RevisedObsList          RSM;
 
     PointIDList undefined_xy_z_;      // revision of points
     int pocbod_;
     bool tst_redbod_;
 
-    ObservationList removed_obs;     // revision of observations
+    ObservationList removed_obs;      // revision of observations
     int pocmer_;
     bool tst_redmer_;
 
@@ -344,7 +361,6 @@ namespace GNU_gama { namespace local
     Index* min_x_;
 
     bool   gons_;
-    int    xml_covband_;
 
     // preparation for design matrix
 
