@@ -1,6 +1,6 @@
 /*
     GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2006, 2012  Ales Cepek <cepek@gnu.org>
+    Copyright (C) 2006, 2012, 2014  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
 
@@ -27,6 +27,7 @@
 #include <gnu_gama/xml/localnetwork_adjustment_results.h>
 #include <gnu_gama/intfloat.h>
 #include <gnu_gama/xml/htmlparser.h>
+#include <gnu_gama/xsd.h>
 
 using namespace std;
 using namespace GNU_gama;
@@ -40,9 +41,11 @@ void LocalNetworkAdjustmentResults::init()
   network_general_parameters.gama_local_version.  clear();
   network_general_parameters.gama_local_algorithm.clear();
   network_general_parameters.gama_local_compiler. clear();
-  network_general_parameters.epoch.  clear();
-  network_general_parameters.axes_xy.clear();
-  network_general_parameters.angles. clear();
+  network_general_parameters.axes_xy.  clear();
+  network_general_parameters.angles.   clear();
+  network_general_parameters.epoch.    clear();
+  network_general_parameters.latitude. clear();
+  network_general_parameters.ellipsoid.clear();
 
   coordinates_summary.adjusted.xyz = 0;
   coordinates_summary.adjusted.xy  = 0;
@@ -172,6 +175,9 @@ void LocalNetworkAdjustmentResults::Parser::init()
       tagfun[s][t] = &Parser::unknown;
 
   tagfun[s_start                              ][t_gama_local_adjustment          ] = &Parser::gama_local_adjustment;
+  tagfun[s_gama_local_adjustment              ][t_error_xml                      ] = &Parser::error_xml;
+  tagfun[s_error_xml                          ][t_description                    ] = &Parser::error_xml_description;
+  tagfun[s_error_xml                          ][t_line_number                    ] = &Parser::error_xml_line_number;
   tagfun[s_gama_local_adjustment              ][t_description                    ] = &Parser::description;
   tagfun[s_description_end                    ][t_network_general_parameters     ] = &Parser::network_general_parameters;
   tagfun[s_network_general_parameters_end     ][t_network_processing_summary     ] = &Parser::network_processing_summary;
@@ -331,6 +337,7 @@ int LocalNetworkAdjustmentResults::Parser::tag(const char* c)
       if (!strcmp(c, "equations"                 )) return t_equations;
       if (!strcmp(c, "err-adj"                   )) return t_err_adj;
       if (!strcmp(c, "err-obs"                   )) return t_err_obs;
+      if (!strcmp(c, "error"                     )) return t_error_xml;
       break;
     case 'f':
       if (!strcmp(c, "f"                         )) return t_f;
@@ -353,6 +360,7 @@ int LocalNetworkAdjustmentResults::Parser::tag(const char* c)
     case 'l':
       if (!strcmp(c, "left"                      )) return t_left;
       if (!strcmp(c, "lower"                     )) return t_lower;
+      if (!strcmp(c, "lineNumber"                )) return t_line_number;
       break;
     case 'n':
       if (!strcmp(c, "network-general-parameters")) return t_network_general_parameters;
@@ -472,6 +480,26 @@ void LocalNetworkAdjustmentResults::Parser::gama_local_adjustment(bool start)
     {
       stack.push(&Parser::gama_local_adjustment);
       set_state(s_gama_local_adjustment);
+
+      while (*attributes)
+        {
+          string atr = *attributes++;
+          string val = *attributes++;
+
+          if (atr == "xmlns")
+            {
+              if (val != XSD_GAMA_LOCAL_ADJUSTMENT)
+                {
+                  error("bad namespace xmlns=\"" + val + "\"");
+                  return;
+                }
+            }
+          else
+            {
+              error("unknown attribute");
+              return;
+            }
+        }
     }
   else
     {
@@ -480,6 +508,68 @@ void LocalNetworkAdjustmentResults::Parser::gama_local_adjustment(bool start)
 }
 
 
+void LocalNetworkAdjustmentResults::Parser::error_xml(bool start)
+{
+  if (start)
+    {
+      stack.push(&Parser::error_xml);
+      set_state(s_error_xml);
+
+      adj->xmlerror.clear();
+      while (*attributes)
+        {
+          string atr = *attributes++;
+          string val = *attributes++;
+
+          if (atr == "category")
+            adj->xmlerror.setCategory(val);
+          else
+            {
+              error("bad attribute in <error>");
+              return;
+            }
+        }
+      if (adj->xmlerror.getCategory().empty())
+        {
+          error("Attribute 'category' is not defined in <error>");
+          return;
+        }
+    }
+  else
+    {
+      set_state(s_error_xml_end);
+    }
+}
+
+
+void LocalNetworkAdjustmentResults::Parser::error_xml_description(bool start)
+{
+  if (start)
+    {
+      stack.push(&Parser::error_xml_description);
+    }
+  else
+    {
+      adj->xmlerror.setDescription(data);
+      set_state(s_error_xml);
+    }
+}
+
+
+void LocalNetworkAdjustmentResults::Parser::error_xml_line_number(bool start)
+{
+  if (start)
+    {
+      stack.push(&Parser::error_xml_line_number);
+    }
+  else
+    {
+      adj->xmlerror.setLineNumber(get_int());
+      set_state(s_error_xml);
+    }
+}
+
+
 void LocalNetworkAdjustmentResults::Parser::description(bool start)
 {
   if (start)
@@ -511,12 +601,16 @@ void LocalNetworkAdjustmentResults::Parser::network_general_parameters(bool star
             adj->network_general_parameters.gama_local_algorithm = val;
           else if (atr == "gama-local-compiler")
             adj->network_general_parameters.gama_local_compiler = val;
-          else if (atr == "epoch")
-            adj->network_general_parameters.epoch = val;
           else if (atr == "axes-xy")
             adj->network_general_parameters.axes_xy = val;
           else if (atr == "angles")
             adj->network_general_parameters.angles = val;
+          else if (atr == "epoch")
+            adj->network_general_parameters.epoch = val;
+          else if (atr == "latitude")
+            adj->network_general_parameters.latitude = val;
+          else if (atr == "ellipsoid")
+            adj->network_general_parameters.ellipsoid = val;
           else
             {
               error("unknown attribute");
