@@ -1,6 +1,6 @@
 /*
-    C++ Matrix/Vector templates (GNU Gama / matvec 1.0.01)
-    Copyright (C) 1999, 2007  Ales Cepek <cepek@gnu.org>
+    C++ Matrix/Vector templates (GNU Gama / matvec)
+    Copyright (C) 1999, 2007, 2012  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ Matrix/Vector template library.
 
@@ -23,7 +23,6 @@
 #define GNU_gama_gMatVec_Vec__h_
 
 #include <iostream>
-#include <cstdarg>
 #include <cmath>
 #include <matvec/vecbase.h>
 
@@ -41,43 +40,24 @@ public:
   Vec() {}
   Vec(Index nsz) : VecBase<Float, Exc>(nsz) {}
   Vec(const VecBase<Float, Exc>& v) : VecBase<Float, Exc>(v) {}
-  Vec(Index nsz, Float m11 ...) : VecBase<Float, Exc>(nsz)
-    {
-         using namespace std;
-         iterator p=this->begin();
-         iterator e=this->end();
-         if (p == e)
-            throw Exc(Exception::BadRank, "Vec::Vec(Index, Float ...)");
-         *p = m11;
-         ++p;
-
-         va_list  ap;
-         va_start(ap, m11);
-         while (p!=e)
-            {
-               *p = va_arg(ap, Float);
-               ++p;
-            }
-         va_end(ap);
-    }
 
   Vec operator*(Float f) const {
-    Vec t(this->dim()); mul(f, t); return t;
+    Vec t(this->dim()); this->mul(f, t); return t;
   }
   Vec operator+(const Vec &x) const {
-    Vec t(this->dim()); add(x, t); return t;
+    Vec t(this->dim()); this->add(x, t); return t;
   }
   Vec operator-(const Vec &x) const {
-    Vec t(this->dim()); sub(x, t); return t;
+    Vec t(this->dim()); this->sub(x, t); return t;
   }
 
-  Vec& operator*=(Float f)      { mul(f, *this); return *this; }
-  Vec& operator+=(const Vec &x) { add(x, *this); return *this; }
-  Vec& operator-=(const Vec &x) { sub(x, *this); return *this; }
+  Vec& operator*=(Float f)      { this->mul(f, *this); return *this; }
+  Vec& operator+=(const Vec &x) { this->add(x, *this); return *this; }
+  Vec& operator-=(const Vec &x) { this->sub(x, *this); return *this; }
 
   typename MatVecBase<Float, Exc>::ListInitialiser operator=(Float x)
   {
-    return list_init(x);
+    return this->list_init(x);
   }
 
 };
