@@ -1,7 +1,8 @@
 /*
     GNU Gama -- adjustment of geodetic networks
     Copyright (C) 2010 Ales Cepek <cepek@gnu.org>, 2010 Jiri Novak
-    <jiri.novak@petriny.net>, 2010 Vaclav Petras <vaclav.petras@fsv.cvut.cz>
+    <jiri.novak@petriny.net>, 2010 Vaclav Petras <vaclav.petras@fsv.cvut.cz>,
+    2013 Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
 
@@ -21,6 +22,13 @@
 */
 
 
+create table gnu_gama_local_schema_version (
+   major integer default 1 not null check (major = 1),
+   minor integer default 1 not null check (minor = 1),
+   primary key (major, minor)
+);
+insert into gnu_gama_local_schema_version (major, minor) values (1, 1);
+
 create table gnu_gama_local_configurations (
    conf_id   integer primary key,
    conf_name varchar(60) not null unique,
@@ -31,10 +39,11 @@ create table gnu_gama_local_configurations (
    update_cc varchar(3) default 'no' not null check (update_cc in ('yes', 'no')),
    axes_xy   varchar(2) default 'ne' not null check (axes_xy in ('ne', 'sw', 'es', 'wn', 'en', 'nw', 'se', 'ws')),
    angles    varchar(12) default 'left-handed' not null check (angles in ('left-handed', 'right-handed')),
-   epoch     double precision default 0.0 not null,
-   algorithm varchar(12) default 'svd' not null check (algorithm in ('svd', 'gso', 'cholesky', 'envelope')),
-   ang_units int default 400 not null check (ang_units in (400, 360)),
-   latitude  double precision default 50 not null,
+   ang_units integer default 400 not null check (ang_units in (400, 360)),
+   cov_band  integer default -1 not null check (cov_band >= -1),
+   algorithm varchar(12) check (algorithm in ('svd', 'gso', 'cholesky', 'envelope')),
+   epoch     double precision,
+   latitude  double precision,
    ellipsoid varchar(20)
 );
 
@@ -81,7 +90,7 @@ create table gnu_gama_local_obs (
    conf_id   integer,
    ccluster  integer,
    indx      integer check (indx > 0),
-   tag       varchar(10) check (tag in ('direction', 'distance', 'angle', 's-distance', 'z-angle', 'dh')),
+   tag       varchar(10) check (tag in ('direction', 'distance', 'angle', 's-distance', 'z-angle', 'azimuth', 'dh')),
    from_id   varchar(80) not null,
    to_id     varchar(80) not null,
    to_id2    varchar(80),
